StackNode

Struct StackNode 

#[repr(C)]
pub struct StackNode { pub next: *mut StackNode, pub text: [Tchar; 1], }
A node of the installer’s GlobalAlloc’d singly linked stack.

text is declared as a one-element array in C but is allocated with room for string_size characters. Never construct one by value.

Fields

next: *mut StackNode

Next node, or null at the bottom of the stack.

text: [Tchar; 1]

Start of the NUL-terminated string. Really [Tchar; string_size].

Implementations

Source

impl StackNode

pub const fn alloc_size(string_size: usize) -> usize

Byte size of a node able to hold string_size characters, matching GlobalAlloc(GPTR, sizeof(stack_t) + g_stringsize * sizeof(TCHAR)).