#[repr(C)]pub struct StackNode {
pub next: *mut StackNode,
pub text: [Tchar; 1],
}Expand description
A node of the installer’s GlobalAlloc’d singly linked stack.
text is declared as a one-element array in C but is allocated with room
for string_size characters. Never construct one by value.
Fields
next: *mut StackNodeNext node, or null at the bottom of the stack.
text: [Tchar; 1]Start of the NUL-terminated string. Really [Tchar; string_size].
Implementations