pub struct Variables { /* private fields */ }Expand description
Handle to the installer’s variables array.
Implementations
Sourceimpl Variables
impl Variables
Sourcepub fn string_size(&self) -> usize
pub fn string_size(&self) -> usize
The calling installer’s NSIS_MAX_STRLEN, in characters.
Sourcepub fn get(&self, var: Var) -> String
pub fn get(&self, var: Var) -> String
Reads a variable.
Returns an empty string when the installer passed no variables array,
because there is nothing sensible to read and $0 is empty by default.